@@ -492,7 +492,7 @@ WPrefDialog::slotTrackDown()
     return;
   }
   int     nIndex = ListBoxTracks->index(ItemSelected);
-  if ( (ListBoxTracks->count() - 1) == (u_int)nIndex ) {  // bottom item
+  if ( (ListBoxTracks->count() - 1) == static_cast<uint>(nIndex) ) {  // bottom item
     return;
   }
 
