@@ -206,7 +206,7 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
   int nCount = nolTracks.count();
   for ( i = 0; i < nCount; i++ ) {
     WVoxTrack *VoxTrackNew = new WVoxTrack(
-                                   nolTracks.item(i), 
+                                   CTrackInf(nolTracks.item(i)), 
                                    timeMaxSessionLength, 
                                    FrameTracks);
     QString strTrackName = VoxTrackNew->name();
@@ -577,7 +577,7 @@ WVoxBase::stateInDOM(QDomDocument* pDoc)
   int nCount = vTrackOrder.size();
   int i;
   for ( i = 0; i < nCount; i++ ) {
-    eleTracks.appendChild(vTrackOrder[i]->stateInDOM(pDoc));
+    eleTracks.appendChild(vTrackOrder[i]->stateInTrackInf().stateInDOM(pDoc));
   } 
 
   return eleTracks;
